rlandfire-package: rlandfire: Interface to 'LANDFIRE Product Service' API

rlandfire-packageR Documentation

rlandfire: Interface to 'LANDFIRE Product Service' API

Description

Provides access to a suite of geospatial data layers for wildfire management, fuel modeling, ecology, natural resource management, climate, conservation, etc., via the 'LANDFIRE' (https://www.landfire.gov/) Product Service ('LFPS') API.

Author(s)

Maintainer: Mark Buckner mab677@cornell.edu (ORCID) [copyright holder]

See Also

Useful links:


rlandfire documentation built on March 19, 2026, 1:06 a.m.